@@ -3,10 +3,11 @@ from ..model.export_avatar_params import ExportAvatarParams
 import os
 import json
 import zipfile
+import shutil
 import win32com.shell.shell as shell
 
 TASK_PARAMS_FILE_NAME = 'nowyou_task_params.txt'
-PLUGIN_PATH_NAME = 'Avatar_export'
+PLUGIN_PATH_NAME = 'nowyou_autorun'
 
 
 def export_avatar(
@@ -19,11 +20,19 @@ def export_avatar(
     # copy plugin script to VStitcher folder
     with zipfile.ZipFile(resource_path('\\vstitcher_plugins\\avatar_export.zip'), 'r') as zip_ref:
         plugin_path = os.path.join(vstitcher_data_path, 'Plugins')
-        # os.mkdir(plugin_path)
+
+        # clean previous version of plugin
+        plugin_folder = os.path.join(plugin_path, PLUGIN_PATH_NAME)
+        if os.path.exists(plugin_folder) and os.path.isdir(plugin_folder):
+            shutil.rmtree(plugin_folder)
+
         zip_ref.extractall(plugin_path)
 
     # set up task params
-    params = ExportAvatarParams(body_sizes, work_path)
+    params = {
+        body_sizes,
+        work_path
+    }
     data = json.dumps(params)
 
     # save JSON params to file
@@ -35,4 +44,5 @@ def export_avatar(
 
     # wait for task finish
     # close VStitcher
+    # delete plugin
     # process result
